<?php
/**
 * Yuno Design Settings panel at Theme Customizer
 *
 * @package Yuno
 * @since 1.0.0
 */

add_action( 'customize_register', 'yuno_design_settings_register' );

function yuno_design_settings_register( $wp_customize ) {

    /**
     * Add Design Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yuno_design_settings_panel',
	    array(
	        'priority'       => 10,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => esc_html__( 'Design Settings', 'yuno' ),
	    )
    );

    /*---------------------------------------------------------------------------------------------------------------*/

    /**
     * Archive Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yuno_archive_settings_section',
        array(
            'title'    => esc_html__( 'Archive Page', 'yuno' ),
            'panel'    => 'yuno_design_settings_panel',
            'priority' => 5,
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_meta_tags_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new yuno_Customizer_Heading(
        $wp_customize,
            'yuno_meta_tags_heading',
            array(
                'label'    => esc_html__( 'Content', 'yuno' ),
                'section'    => 'yuno_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    /**
     * Switch option for Author name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_author',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_author',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Author', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Author" for post.', 'yuno' ),
                'section'       => 'yuno_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Date name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_date',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_date',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Date', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Date" for post.', 'yuno' ),
                'section'       => 'yuno_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Featured Image name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_fimage',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_fimage',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Featured Image', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Featured Image" for post.', 'yuno' ),
                'section'       => 'yuno_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

   	/**
     * Switch option for Category name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_category',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_category',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Category', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Category" for post.', 'yuno' ),
                'section'       => 'yuno_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Tags name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_tags',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_tags',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Tags', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Tags" for post.', 'yuno' ),
                'section'       => 'yuno_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );


    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_post_display_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new yuno_Customizer_Heading(
        $wp_customize,
            'yuno_post_display_heading',
            array(
                'label'    => esc_html__( 'Display Options', 'yuno' ),
                'section'  => 'yuno_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    /**
     * Text field for post excerpt length
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_blog_excerpt_length',
        array(
            'default'           => 30,
            'sanitize_callback' => 'yuno_sanitize_number_absint'
            )
    );
    $wp_customize->add_control(
        'yuno_blog_excerpt_length',
        array(
            'type'         => 'number',
            'label'        => esc_html__( 'Post excerpt length( content length )', 'yuno' ),
            'description'  => esc_html__( 'Enter content length in numbers.', 'yuno' ),
            'section'      => 'yuno_archive_settings_section',
            'priority'     => 15
        )
    );

    /**
     * Text field for archive read more
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_archive_read_more_text',
        array(
            'default'           => esc_html__( 'Read More', 'yuno' ),
            'sanitize_callback' => 'sanitize_text_field'
            )
    );
    $wp_customize->add_control(
        'yuno_archive_read_more_text',
        array(
            'type'         => 'text',
            'label'        => esc_html__( 'Read More Text', 'yuno' ),
            'description'  => esc_html__( 'Enter read more button text for archive page.', 'yuno' ),
            'section'      => 'yuno_archive_settings_section',
            'priority'     => 15
        )
    );

    /**
     * Radio field for post content
     * 
     *  @since 1.0.0
     */
    $wp_customize->add_setting( 
        'yuno_radio_post_content',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'excerpt',
            'sanitize_callback' => 'yuno_sanitize_radio_option',
        ) 
    );
    $wp_customize->add_control( 
        'yuno_radio_post_content',
        array(
            'type'        => 'radio',
            'section'     => 'yuno_archive_settings_section',
            'priority'    => 20,
            'label'       => esc_html__( 'Content type', 'yuno' ),
            'description' => esc_html__( 'Select content type to diplay post text.', 'yuno' ),
            'choices'     => array(
                'full'    => esc_html__( 'Full content', 'yuno' ),
                'excerpt' => esc_html__( 'Excerpt', 'yuno' )
            ),
        )
    );

    /**
     * Radio field for post pagination
     * 
     *  @since 1.0.0
     */
    $wp_customize->add_setting( 
        'yuno_radio_post_pagination',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'pagination',
            'sanitize_callback' => 'yuno_sanitize_radio_option',
        ) 
    );
    $wp_customize->add_control( 
        'yuno_radio_post_pagination',
        array(
            'type'        => 'radio',
            'section'     => 'yuno_archive_settings_section',
            'priority'    => 20,
            'label'       => esc_html__( 'Post Pagination', 'yuno' ),
            'description' => esc_html__( 'Select pagination for post.', 'yuno' ),
            'choices'     => array(
                'default'    => esc_html__( 'default', 'yuno' ),
                'pagination' => esc_html__( 'Pagination', 'yuno' )
            ),
        )
    );

    /*---------------------------------------------------------------------------------------------------------------*/

    /**
     * Archive Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yuno_single_settings_section',
        array(
            'title'    => esc_html__( 'Single Post', 'yuno' ),
            'panel'    => 'yuno_design_settings_panel',
            'priority' => 5,
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_meta_single_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new yuno_Customizer_Heading(
        $wp_customize,
            'yuno_meta_single_heading',
            array(
                'label'    => esc_html__( 'Content', 'yuno' ),
                'section'    => 'yuno_single_settings_section',
                'priority' => 5,
            )
        )
    );

    /**
     * Switch option for Author name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_author',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_author',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Author', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Author" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Date name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_date',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_date',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Date', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Date" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Featured Image name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_fimage',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_fimage',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Featured Image', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Featured Image" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

   	/**
     * Switch option for Category name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_category',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_category',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Category', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Category" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Tags name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_tags',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_tags',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Tags', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Tags" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_single_display_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new yuno_Customizer_Heading(
        $wp_customize,
            'yuno_single_display_heading',
            array(
                'label'    => esc_html__( 'Display Options', 'yuno' ),
                'section'  => 'yuno_single_settings_section',
                'priority' => 5,
            )
        )
    );

    /**
     * Switch option for Post Navigation name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yuno_show_single_nav',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'yuno_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new yuno_Customize_Switch_Control(
        $wp_customize,
            'yuno_show_single_nav',
            array(
                'type'          => 'yuno-switch',
                'label'         => esc_html__( 'Enable Post Navigation', 'yuno' ),
                'description'   => esc_html__( 'Show/Hide option for "Post Navigation" for post.', 'yuno' ),
                'section'       => 'yuno_single_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'yuno' ),
                    'hide'      => esc_html__( 'Hide', 'yuno' )
                ),
                'priority'      => 5,
            )
        )
    );
}